Package 'PEPRMT'

Title: Peatland Ecosystem Photosynthesis, Respiration and Methane Transport model
Description: PEPRMT-Tidal is a one-dimensional process-based model that predicts gross primary productivity, ecosystem respiration and methane exchange in tidal wetlands at the daily time step. This package contains functions for PEPRMT-Tidal, an updated version of the PEPRMT model. This model is described in detail in Oikawa et al. (2024).
Authors: Patty Y. Oikawa [aut, cre], Abigail S. L. Lewis [aut]
Maintainer: Patty Y. Oikawa <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9100
Built: 2026-05-21 09:52:46 UTC
Source: https://github.com/abbylewis/PEPRMT-Tidal

Help Index


Example data

Description

Data sourced from Oikawa et al."A new coupled biogeochemical modeling approach provides accurate predictions of methane and carbon dioxide fluxes across diverse tidal wetlands." Journal of Geophysical Research: Biogeosciences 129.10 (2024): e2023JG007943. Eddy covariance data are from Ameriflux sites US-Srr, US-Edn, US-LA1, US-PLM, US-Stj See Ameriflux website for site location and information: https://ameriflux.lbl.gov/sites/site-search/ All sites are North American tidal marshes

Usage

example_data

Format

example_data

A data frame with 7,240 rows and 60 columns:

site

Ameriflux site ID

Year

Year

DOY_disc

Discontinuous day of year (starts over at 1 at the beginning of each year)

DOY

Day of year (continuously increases over time)

TA_C

Air temperature (degrees C)

WTD_cm

Water table depth (cm)

PAR_umol_m2_day

Average Photosynthetically active radiation (umol m-2 d-1)

LAI

Leaf Area Index (not used in this dataset so defaulted to NaN)

EVI

daily Enhanced Vegetation Index from Landsat

FPAR

FPAR flag for GPP module. Set to 0 if using EVI. Set to 1 if using LAI

LUE

Light Use Efficiency. Computed by taking the average of daily measured GPP divided by daily average PAR for each site

Wetland_age_years

Age of wetland in years

Salinity_daily_ave_ppt

Daily average salinity (ppt)

NO3_mg_L

Daily average NO3 (mg/L)

SOM_MEM_gC_m3

Available soil organic matter (gC m-3) in the top 1 m of soil predicted by the Cohort Marsh Equilibrium (CMEM) model

CO2_gC_m2_day

Measured Net Ecosystem Exchange (NEE) of CO2 (gC-CO2 m-2 day-1)

GPP_gC_m2_day

Gross Primary Productivity (GPP) partitioned from NEE (gC-CO2 m-2 day-1)

Reco_gC_m2_day

Ecosystem Respiration (Reco) partitioned from NEE (gC-CO2 m-2 day-1)

CH4_gC_m2_day

Measured Net Ecosystem Exchange of CH4 (gC-CH4 m-2 day-1)

...

Oikawa et al. 2024


Methane Exchange (CH4)

Description

Methane production and transport module of the PEPRMT model (v1.0).

Usage

PEPRMT_CH4(
  data,
  wetland_type,
  Ea_SOM_CH4 = 14.9025078 + 67.1,
  kM_SOM_CH4 = 0.4644174 + 17,
  Ea_labile_CH4 = 16.7845002 + 71.1,
  kM_labile_CH4 = 0.4359649 + 23,
  Ea_oxi_CH4 = 15.8857612 + 75.4,
  kM_oxi_CH4 = 0.5120464 + 23,
  kI_SO4 = 486.4106939,
  kI_NO3 = 0.1020278,
  k_plant_oxi = 0.35
)

Arguments

data

Data frame containing 18 required columns used as model inputs. See Details for expected column names.

wetland_type

Integer indicating wetland class: 1 = Freshwater peatland, 2 = Tidal wetland.

Ea_SOM_CH4

Activation energy for methane production from soil organic matter (kJ mol^-1)

kM_SOM_CH4

Half-saturation constant for SOM methane production (g C m^-3 soil)

Ea_labile_CH4

Activation energy for methane production from labile carbon (kJ mol^-1)

kM_labile_CH4

Half-saturation constant for labile methane production (g C m^-3 soil)

Ea_oxi_CH4

Activation energy for methane oxidation (kJ mol^-1)

kM_oxi_CH4

Half-saturation constant for methane oxidation (g C m^-3 soil)

kI_SO4

– Sulfate inhibition constant (mg L^-1)

kI_NO3

– Nitrate inhibition constant (mg L^-1)

k_plant_oxi

Fraction of CH4 oxidized during transport

Details

Runs the PEPRMT methane production and transport module for freshwater peatlands or tidal wetlands at a daily time step. Default parameter values were determined via MCMC Bayesian fitting (Oikawa et al. 2024).

The PEPRMT model was originally parameterized for restored freshwater wetlands in the Sacramento–San Joaquin River Delta, California, USA (Oikawa et al. 2017) and later updated for tidal wetlands with inhibition of methane production in response to salinity and nitrate (Oikawa et al. 2024).

Modules are intended to be run sequentially: PEPRMT_GPP, then PEPRMT_Reco, then PEPRMT_CH4.

All variables are expected at a daily time step.

All PEPRMT modules use the same input structure, although not all variables are used in every module.

Required data columns:

  1. Continuous day of year

  2. Discontinuous day of year

  3. Year

  4. Air temperature (°C)

  5. Water table depth (cm)

  6. PAR (µmol m^-2 d^-1)

  7. Leaf Area Index

  8. Greenness Index

  9. FPAR flag

  10. Light Use Efficiency

  11. Wetland age (years)

  12. Salinity (ppt)

  13. NO3 (mg L^-1)

  14. Soil organic matter (g C m^-3)

  15. Site identifier

  16. Modeled GPP (g C m^-2 day^-1)

  17. Modeled Reco (g C m^-2 day^-1)

  18. Net ecosystem exchange (g C m^-2 day^-1)

Value

Updated dataframe containing:

CH4_mod

total methane emitted (g C CH4 m^-2 day^-1)

Plant_flux_net

net methane flux via plant-mediated transport (g C CH4 m^-2 day^-1)

Hydro_flux

net diffusive methane flux from water to atmosphere (g C CH4 m^-2 day^-1)

M1

methane pool produced from labile soil carbon (g C CH4 m^-3, top meter of soil and water)

M2

methane pool produced from soil organic carbon (g C CH4 m^-3, top meter of soil and water)

trans2

fraction of methane released via plant-mediated transport (unitless)

References

Oikawa, P. Y., Jenerette, G. D., Knox, S. H., Sturtevant, C., Verfaillie, J., Dronova, I., Poindexter, C. M., Eichelmann, E., & Baldocchi, D. D. (2017). Evaluation of a hierarchy of models reveals importance of substrate limitation for predicting carbon dioxide and methane exchange in restored wetlands. Journal of Geophysical Research: Biogeosciences, 122(1), 145–167. https://doi.org/10.1002/2016JG003438

Oikawa, P. Y., Sihi, D., Forbrich, I., Fluet-Chouinard, E., Najarro, M., Thomas, O., Shahan, J., Arias-Ortiz, A., Russell, S., Knox, S. H., McNicol, G., Wolfe, J., Windham-Myers, L., Stuart-Haentjens, E., Bridgham, S. D., Needelman, B., Vargas, R., Schäfer, K., Ward, E. J., Megonigal, P., & Holmquist, J. (2024). A New Coupled Biogeochemical Modeling Approach Provides Accurate Predictions of Methane and Carbon Dioxide Fluxes Across Diverse Tidal Wetlands. Journal of Geophysical Research: Biogeosciences, 129(10), e2023JG007943. https://doi.org/10.1029/2023JG007943

Examples

# Example
# data(example_dataset)
# theta <- c(14.9025078, 0.4644174, 16.7845002, 0.4359649, 15.8857612, 
# 0.5120464, 486.4106939, 0.1020278)
# out <- PEPRMT_CH4(theta, example_dataset, wetland_type = 2)

Gross Primary Productivity (GPP)

Description

Gross Primary Productivity (GPP) module of the PEPRMT model (v1.0). Default values were determined via MCMC Bayesian fitting (Oikawa et al. 2023).

Usage

PEPRMT_GPP(
  data,
  a0 = 0.7479271,
  a1 = 1.0497113,
  Ha = 149.468171 + 30,
  Hd = 94.4532674 + 100,
  T_opt_GPP = 25 + 274.15
)

Arguments

data

Data frame containing 15 required columns used as model inputs. See Details for expected column structure.

a0

Empirical intercept parameter for the fPAR scaling function (unitless).

a1

Empirical slope parameter for the fPAR scaling function (unitless).

Ha

Activation energy governing the temperature response of photosynthesis for general crop-type vegetation (kJ mol^-1). Controls the rate of increase in GPP with temperature below the thermal optimum.

Hd

Deactivation energy controlling the decline in photosynthesis above the thermal optimum (kJ mol^-1). Determines the rate of decrease in GPP at high temperatures.

T_opt_GPP

Temperature optimum for GPP

Details

Runs the PEPRMT gross primary productivity module for freshwater peatlands or tidal wetlands at a daily time step.

The PEPRMT model was originally parameterized for restored freshwater wetlands in the Sacramento–San Joaquin River Delta, California, USA (Oikawa et al. 2017) and later updated for tidal wetlands (Oikawa et al. 2023).

Modules are intended to be run sequentially: PEPRMT_GPP, then PEPRMT_Reco, then PEPRMT_CH4.

All variables are expected at a daily time step.

This model predicts GPP using a light use efficiency equation GPP can be predicted using leaf area index (LAI) or a greenness index from Phenocam data or remote sensing such as EVI or NDVI PEPRMT-Tidal applied in Oikawa et al. 2023 uses EVI from Landsat

Required data columns:

  1. Continuous day of year

  2. Discontinuous day of year

  3. Year

  4. Air temperature (°C)

  5. Water table depth (cm)

  6. PAR (µmol m^-2 d^-1)

  7. Leaf Area Index

  8. Greenness Index

  9. FPAR flag

  10. Light Use Efficiency

  11. Wetland age (years)

  12. Salinity (ppt)

  13. NO3 (mg L^-1)

  14. Soil organic matter (g C m^-3)

  15. Site identifier

Value

Updated dataframe containing:

GPP

gross primary productivity (g C CO2 m^-2 d^-1)

APAR

absorbed photosynthetically active radiation (umol m^-2 d^-1)

References

Oikawa, P. Y., Jenerette, G. D., Knox, S. H., Sturtevant, C., Verfaillie, J., Dronova, I., Poindexter, C. M., Eichelmann, E., & Baldocchi, D. D. (2017). Evaluation of a hierarchy of models reveals importance of substrate limitation for predicting carbon dioxide and methane exchange in restored wetlands. Journal of Geophysical Research: Biogeosciences, 122(1), 145–167. https://doi.org/10.1002/2016JG003438

Oikawa, P. Y., Sihi, D., Forbrich, I., Fluet-Chouinard, E., Najarro, M., Thomas, O., Shahan, J., Arias-Ortiz, A., Russell, S., Knox, S. H., McNicol, G., Wolfe, J., Windham-Myers, L., Stuart-Haentjens, E., Bridgham, S. D., Needelman, B., Vargas, R., Schäfer, K., Ward, E. J., Megonigal, P., & Holmquist, J. (2024). A New Coupled Biogeochemical Modeling Approach Provides Accurate Predictions of Methane and Carbon Dioxide Fluxes Across Diverse Tidal Wetlands. Journal of Geophysical Research: Biogeosciences, 129(10), e2023JG007943. https://doi.org/10.1029/2023JG007943

Examples

# Example
# data(example_dataset)
# out <- PEPRMT_GPP(theta, example_dataset, wetland_type = 2)

Ecosystem Respiration (Reco)

Description

Ecosystem respiration (Reco) module of the PEPRMT model (v1.0).

Usage

PEPRMT_Reco(
  data,
  wetland_type,
  Ea_SOM = 18.41329,
  kM_SOM = 1487.65701,
  Ea_labile = 11.65972,
  kM_labile = 61.29611
)

Arguments

data

Data frame containing 16 required columns used as model inputs. See Details for expected column structure.

wetland_type

Integer indicating wetland class: 1 = Freshwater peatland, 2 = Tidal wetland.

Ea_SOM

– Activation energy controlling the temperature sensitivity of decomposition from the soil organic matter (SOM) pool (kJ mol^-1).

kM_SOM

– Half-saturation constant for microbial decomposition of the SOM pool (g C m^-3 soil). Determines substrate limitation strength for SOM respiration.

Ea_labile

– Activation energy controlling the temperature sensitivity of decomposition from the labile carbon pool (kJ mol^-1).

kM_labile

– Half-saturation constant for microbial decomposition of the labile carbon pool (g C m^-3 soil). Determines substrate limitation strength for labile respiration.

Details

Runs the PEPRMT ecosystem respiration module for freshwater peatlands or tidal wetlands at a daily time step.

The PEPRMT model was originally parameterized for restored freshwater wetlands in the Sacramento–San Joaquin River Delta, California, USA (Oikawa et al. 2017) and later updated for tidal wetlands (Oikawa et al. 2023).

Modules are intended to be run sequentially: PEPRMT_GPP, then PEPRMT_Reco, then PEPRMT_CH4.

All variables are expected at a daily time step.

Required data columns:

  1. Continuous day of year

  2. Discontinuous day of year

  3. Year

  4. Air temperature (°C)

  5. Water table depth (cm)

  6. PAR (µmol m^-2 d^-1)

  7. Leaf Area Index

  8. Greenness Index

  9. FPAR flag

  10. Light Use Efficiency

  11. Wetland age (years)

  12. Salinity (ppt)

  13. NO3 (mg L^-1)

  14. Soil organic matter (g C m^-3)

  15. Site identifier

  16. Modeled GPP (g C m^-2 day^-1)

Value

Updated dataframe containing:

Reco_mod

Total ecosystem respiration (g C CO2 m^-2 day^-1)

NEE_mod

Net ecosystem exchange of CO2 (g C CO2 m^-2 day^-1)

S1

Labile soil carbon pool (g C m^-3, top meter of soil)

S2

Soil organic carbon pool (g C m^-3, top meter of soil)

References

Oikawa, P. Y., Jenerette, G. D., Knox, S. H., Sturtevant, C., Verfaillie, J., Dronova, I., Poindexter, C. M., Eichelmann, E., & Baldocchi, D. D. (2017). Evaluation of a hierarchy of models reveals importance of substrate limitation for predicting carbon dioxide and methane exchange in restored wetlands. Journal of Geophysical Research: Biogeosciences, 122(1), 145–167. https://doi.org/10.1002/2016JG003438

Oikawa, P. Y., Sihi, D., Forbrich, I., Fluet-Chouinard, E., Najarro, M., Thomas, O., Shahan, J., Arias-Ortiz, A., Russell, S., Knox, S. H., McNicol, G., Wolfe, J., Windham-Myers, L., Stuart-Haentjens, E., Bridgham, S. D., Needelman, B., Vargas, R., Schäfer, K., Ward, E. J., Megonigal, P., & Holmquist, J. (2024). A New Coupled Biogeochemical Modeling Approach Provides Accurate Predictions of Methane and Carbon Dioxide Fluxes Across Diverse Tidal Wetlands. Journal of Geophysical Research: Biogeosciences, 129(10), e2023JG007943. https://doi.org/10.1029/2023JG007943

Examples

# Example
# data(example_dataset)
# theta <- c(18.4, 1487.6, 11.6, 61.3)
# out <- PEPRMT_Reco(theta, example_dataset, wetland_type = 2)

run_PEPRMT

Description

Wrapper function to run all steps of the PEPRMT model (v1.0).

Usage

run_PEPRMT(
  data,
  wetland_type,
  a0 = 0.7479271,
  a1 = 1.0497113,
  Ha = 149.468171 + 30,
  Hd = 94.4532674 + 100,
  T_opt_GPP = 25 + 274.15,
  Ea_SOM = 18.41329,
  kM_SOM = 1487.65701,
  Ea_labile = 11.65972,
  kM_labile = 61.29611,
  Ea_SOM_CH4 = 14.9025078 + 67.1,
  kM_SOM_CH4 = 0.4644174 + 17,
  Ea_labile_CH4 = 16.7845002 + 71.1,
  kM_labile_CH4 = 0.4359649 + 23,
  Ea_oxi_CH4 = 15.8857612 + 75.4,
  kM_oxi_CH4 = 0.5120464 + 23,
  kI_SO4 = 486.4106939,
  kI_NO3 = 0.1020278,
  k_plant_oxi = 0.35
)

Arguments

data

Data frame containing 15 required columns used as model inputs. See Details for expected column structure.

wetland_type

Integer indicating wetland class: 1 = Freshwater peatland, 2 = Tidal wetland.

a0

Empirical intercept parameter for the fPAR scaling function (unitless). Used in GPP module.

a1

Empirical slope parameter for the fPAR scaling function (unitless). Used in GPP module.

Ha

Activation energy governing the temperature response of photosynthesis for general crop-type vegetation (kJ mol^-1). Controls the rate of increase in GPP with temperature below the thermal optimum. Used in GPP module.

Hd

Deactivation energy controlling the decline in photosynthesis above the thermal optimum (kJ mol^-1). Determines the rate of decrease in GPP at high temperatures. Used in GPP module.

T_opt_GPP

Temperature optimum for GPP. Used in GPP module.

Ea_SOM

– Activation energy controlling the temperature sensitivity of decomposition from the soil organic matter (SOM) pool (kJ mol^-1). Used in Reco module.

kM_SOM

– Half-saturation constant for microbial decomposition of the SOM pool (g C m^-3 soil). Determines substrate limitation strength for SOM respiration. Used in Reco module.

Ea_labile

Activation energy controlling the temperature sensitivity of decomposition from the labile carbon pool (kJ mol^-1). Used in Reco module.

kM_labile

Half-saturation constant for microbial decomposition of the labile carbon pool (g C m^-3 soil). Determines substrate limitation strength for labile respiration. Used in Reco module.

Ea_SOM_CH4

Activation energy for methane production from soil organic matter (kJ mol^-1). Used in CH4 module.

kM_SOM_CH4

Half-saturation constant for SOM methane production (g C m^-3 soil). Used in CH4 module.

Ea_labile_CH4

Activation energy for methane production from labile carbon (kJ mol^-1). Used in CH4 module.

kM_labile_CH4

Half-saturation constant for labile methane production (g C m^-3 soil). Used in CH4 module.

Ea_oxi_CH4

Activation energy for methane oxidation (kJ mol^-1). Used in CH4 module.

kM_oxi_CH4

Half-saturation constant for methane oxidation (g C m^-3 soil). Used in CH4 module.

kI_SO4

Sulfate inhibition constant (mg L^-1). Used in CH4 module.

kI_NO3

Nitrate inhibition constant (mg L^-1). Used in CH4 module.

k_plant_oxi

Fraction of CH4 oxidized during transport. Used in CH4 module.

Details

Runs all PEPRMT functions and returns an output dataframe with modeled GPP, Reco, and CH4

The PEPRMT model was originally parameterized for restored freshwater wetlands in the Sacramento–San Joaquin River Delta, California, USA (Oikawa et al. 2017) and later updated for tidal wetlands with inhibition of methane production in response to salinity and nitrate (Oikawa et al. 2024).

Modules are run sequentially: PEPRMT_GPP, then PEPRMT_Reco, then PEPRMT_CH4.

All variables are expected at a daily time step.

All PEPRMT modules use the same input structure, although not all variables are used in every module.

Required data columns (order does not matter):

  1. DOY: Continuous day of year

  2. DOY_disc: Discontinuous day of year

  3. Year

  4. TA_C: Air temperature (°C)

  5. WTD_cm: Water table depth (cm)

  6. PAR_umol_m2_day: PAR (µmol m^-2 d^-1)

  7. LAI: Leaf Area Index

  8. EVI: Greenness Index

  9. FPAR: FPAR flag

  10. LUE: Light Use Efficiency

  11. Wetland_age_years: Wetland age (years)

  12. Salinity_daily_ave_ppt: Salinity (ppt)

  13. NO3_mg_L: NO3 (mg L^-1)

  14. SOM_MEM_gC_m3: Soil organic matter (g C m^-3)

  15. site: Site identifier

Value

Updated dataframe containing:

GPP

gross primary productivity (g C CO2 m^-2 day^-1)

APAR

absorbed photosynthetically active radiation (umol m-2 d-1)

Reco_full

Total ecosystem respiration (g C CO2 m^-2 day^-1)

NEE_mod

Net ecosystem exchange of CO2 (g C CO2 m^-2 day^-1)

S1

Labile soil carbon pool (g C m^-3, top meter of soil)

S2

Soil organic carbon pool (g C m^-3, top meter of soil)

pulse_emission_total

total methane emitted (g C CH4 m^-2 day^-1)

Plant_flux_net

net methane flux via plant-mediated transport (g C CH4 m^-2 day^-1)

Hydro_flux

net diffusive methane flux from water to atmosphere (g C CH4 m^-2 day^-1)

M1

methane pool produced from labile soil carbon (g C CH4 m^-3, top meter of soil and water)

M2

methane pool produced from soil organic carbon (g C CH4 m^-3, top meter of soil and water)

trans2

fraction of methane released via plant-mediated transport (unitless)